#include <string.h>
#include <stdlib.h>

#include <X11/Xlib.h>
#include <gdk/gdkx.h>
#include <gtk/gtk.h>
#include <libosso.h>
#include <hildon-1/hildon/hildon.h>

static const char binary[] = "/opt/usr/bin/extkbd";

osso_return_t execute(osso_context_t *osso_context, gpointer parent, gboolean user_activated)
{
    char args[sizeof(binary) + 64];
    Window id = None;

    (void) osso_context;

    if (parent && GTK_WIDGET(parent) && GTK_WIDGET(parent)->window)
    {
        id = gdk_x11_drawable_get_xid(GTK_WIDGET(parent)->window);
	hildon_gtk_window_set_portrait_flags(GTK_WINDOW(parent),HILDON_PORTRAIT_MODE_SUPPORT);
	while (gtk_events_pending ())
	  gtk_main_iteration ();

    }

    sprintf(args, "%s --parent 0x%X %s", binary, (unsigned int) id, user_activated ? " --user" : "");
    return (osso_return_t)system(args);
}

/*osso_return_t save_state(osso_context_t *osso_context, gpointer parent)
{
    (void) osso_context;
    (void) parent;

    return OSSO_OK;
}*/
